pub struct TorusSurface {
pub center: Vec3,
pub axis: Vec3,
pub major_radius: f64,
pub minor_radius: f64,
}Expand description
A circular torus represented by its center, axis, and radii.
Fields
center: Vec3Center of the torus’s generating circle.
axis: Vec3Unit normal of the generating circle’s plane.
major_radius: f64Radius from center to the centerline of the tube.
minor_radius: f64Radius of the torus tube.