SurfaceHint

Enum SurfaceHint 

pub enum SurfaceHint {
    Unknown,
    KnownType {
        surface_type: SurfaceType,
    },
    InitialGuess {
        surface: AnalyticSurface,
        trust: MetadataTrust,
    },
    Constrained {
        surface_type: SurfaceType,
        constraints: SurfaceConstraints,
        trust: MetadataTrust,
    },
    ExactCandidate {
        surface: AnalyticSurface,
    },
}
Optional source knowledge used to guide surface recognition.

Variants



Unknown

No prior surface information is available.



KnownType

The primitive family is known but its parameters are not.

Fields

surface_type: SurfaceType

The known primitive family.



InitialGuess

Numeric parameters are available as a refinement starting point.

Fields

surface: AnalyticSurface

Initial carrier parameters.

trust: MetadataTrust

Confidence assigned to the supplied parameters.



Constrained

The family is known and selected parameter groups may be fixed.

Fields

surface_type: SurfaceType

The required primitive family.

constraints: SurfaceConstraints

Initial values and fixed-parameter mask.

trust: MetadataTrust

Confidence assigned to the supplied constraints.



ExactCandidate

A complete carrier that may be reused after validation.

Fields

surface: AnalyticSurface

The proposed exact carrier.